@@ -1,7 +1,9 @@
+from typing import List
+
 from marshmallow import fields
 
 from ..utils.facet_helpers import searchable
-from .datatypes import DataType
+from .datatypes import DataType, Import
 
 
 class NumberDataType(DataType):
