@@ -1,4 +1,5 @@
 from oarepo_model_builder.utils.jinja import split_package_base_name
+
 from ..builders import OutputBuilder
 from ..outputs.cfg import CFGOutput
 
@@ -12,11 +13,11 @@ class InvenioRecordResourceSetupCfgBuilder(OutputBuilder):
         output: CFGOutput = self.builder.get_output("cfg", "setup.cfg")
 
         register_function = split_package_base_name(
-            self.settings.python.create_blueprint_from_app
+            self.current_model.create_blueprint_from_app
         )
 
         output.add_entry_point(
             "invenio_base.api_blueprints",
-            self.settings.python.record_resource_blueprint_name,
+            self.current_model.record_api_blueprints_setup_cfg,
             f"{register_function[0]}:{register_function[-1]}",
         )
